Tutorial
========

This is a quick tutorial on how to use LivePlots. LivePlots is extremely easy to use and you should be up and running
in no time after readin the simple.py example.

However some things can be said about the installation process.

Installation
------------

Before getting being able to use LivePlots you need a copy of Gnuplot installed on your system.

If You are on a debian based distro, like Ubuntu, just type:

